/*
 * Copyright (c) 2001, 2002 The XDoclet team
 * All rights reserved.
 */
package test.hibernate;

import java.util.Collections;
import java.util.Date;
import java.util.Set;

/**
 * Order Sample
 *
 * @author                sguimont
 * @created               06 December 2002
 * @hibernate.class       table="TB_ORDER"
 * @hibernate.jcs-cache   usage="read-write"
 * @hibernate.query       name="query1" query="select a from b for pleasure 1"
 * @hibernate.query       name="query2" query="select a from b for pleasure 2"
 */
public class Order
{
    private Date    created;
    private String  orderNumber;
    private long    id;
    private double  total;
    private OrderTypeRefValue orderType;
    private int     version;
    private Set     items = Collections.EMPTY_SET;
    private OrderItems2 items2;

    /**
     * Returns the created.
     *
     * @return               Date
     * @hibernate.property   column="DT_CREATED"
     */
    public Date getCreated()
    {
        return created;
    }

    /**
     * Returns the id.
     *
     * @return         long
     * @hibernate.id   column="ID" generator-class="vm.long"
     */
    public long getId()
    {
        return id;
    }

    /**
     * Returns the orderNumber.
     *
     * @return               String
     * @hibernate.property   column="ORDER_NUMBER"
     */
    public String getOrderNumber()
    {
        return orderNumber;
    }

    /**
     * Returns the total.
     *
     * @return               double
     * @hibernate.property   column="TOTAL"
     */
    public double getTotal()
    {
        return total;
    }

    /**
     * Returns the orderType.
     *
     * @return                  OrderTypeRefValue
     * @hibernate.many-to-one   column="ORDER_TYPE_CD" cascade="none"
     */
    public OrderTypeRefValue getOrderType()
    {
        return orderType;
    }

    /**
     * Returns the version.
     *
     * @return              int
     * @hibernate.version   column="VER"
     */
    public int getVersion()
    {
        return version;
    }

    /**
     * Returns the items.
     *
     * @return                                   Set
     * @hibernate.set                            role="items" table="TB_ORDER_ITEM"
     * @hibernate.collection-key                 column="ORDER_ID"
     * @hibernate.collection-composite-element   class="xdoclet.modules.hibernate.test.OrderItems"
     */
    public Set getItems()
    {
        return items;
    }

    /**
     * Returns the items.
     *
     * @return                Set
     * @hibernate.component   class="xdoclet.modules.hibernate.test.OrderItems2"
     */
    public OrderItems2 getOrderItems2()
    {
        return items2;
    }

    /**
     * Sets the created.
     *
     * @param created  The created to set
     */
    public void setCreated(Date created)
    {
        this.created = created;
    }

    /**
     * Sets the id.
     *
     * @param id  The id to set
     */
    public void setId(long id)
    {
        this.id = id;
    }

    /**
     * Sets the orderNumber.
     *
     * @param orderNumber  The orderNumber to set
     */
    public void setOrderNumber(String orderNumber)
    {
        this.orderNumber = orderNumber;
    }

    /**
     * Sets the total.
     *
     * @param total  The total to set
     */
    public void setTotal(double total)
    {
        this.total = total;
    }

    /**
     * Sets the orderType.
     *
     * @param orderType  The orderType to set
     */
    public void setOrderType(OrderTypeRefValue orderType)
    {
        this.orderType = orderType;
    }

    /**
     * Sets the version.
     *
     * @param version  The version to set
     */
    public void setVersion(int version)
    {
        this.version = version;
    }

    public void setOrderItems2(OrderItems2 items2)
    {
        this.items2 = items2;
    }

    /**
     * Sets the items.
     *
     * @param items  The items to set
     */
    public void setItems(Set items)
    {
        this.items = items;
    }
}
